function y = TernarRedlichKister(a,x)
%
% Funkce pot hodnoty dodatkovho objemu ternrn smsi pomoc
% modifikovan Redlich-Kisterovy rovnice v jednom nebo vce bodech

% 1 bod (dkov vektor): x = [x1, x2, x3]
% k bod (matice):        x = [x11, x12, x13;
%                              x21, x22, x23;
%                              ..., ..., ...;
%                              xk1, xk2, xk3]
%
% Koeficienty rovnice A  funkce x jsou ve forme vektoru o delce 10 
% (lze radkovy i sloupcovy)
% 
% y = x1.x2.(A(12)0 + A(12)1.(x1-x2) + ... + A(12)m.(x1-x2)^m) 
%   + x1.x3.(A(13)0 + A(13)1.(x1-x3) + ... + A(13)m.(x1-x3)^m)
%   + x2.x3.(A(23)0 + A(23)1.(x2-x3) + ... + A(23)m.(x2-x3)^m)
%   + x1.x2.x3.(B0 + B1.x1 + B2.x2 + B3.x1^2 + B4.x1.x2 + B5.x2^2)
% 
% nap. pro m = 2 :
% a(1) = A(12)0
% a(2) = A(12)1
% a(3) = A(12)2
% a(4) = A(13)0
% a(5) = A(13)1
% a(6) = A(13)2
% a(7) = A(23)0
% a(8) = A(23)1
% a(9) = A(23)2
% a(10) = B0
% a(11) = B1
% a(12) = B2
% a(13) = B3
% a(14) = B4
% a(15) = B5

global nbin nter
y = 0;
kk = 3*(nbin + 1);
for k = 1:nbin+1
    y = y + ...
        x(:,1).*x(:,2)*a(k).*(x(:,1)-x(:,2)).^(k-1) + ...
        x(:,1).*x(:,3)*a(k+nbin+1).*(x(:,1)-x(:,3)).^(k-1) + ...
        x(:,2).*x(:,3)*a(k+2*(nbin+1)).*(x(:,2)-x(:,3)).^(k-1);
end
if nter >= 0
    y = y + x(:,1).*x(:,2).*x(:,3).* ...
        a(kk+1);
end
if nter >= 1    
    y = y + x(:,1).*x(:,2).*x(:,3).* ...
        (a(kk+2)*x(:,1) + a(kk+3)*x(:,2));
end
if nter == 2    
    y = y + x(:,1).*x(:,2).*x(:,3).* ...
        (a(kk+4)*x(:,1).^2 + a(kk+5)*x(:,1).*x(:,2) + a(kk+6)*x(:,2).^2);
end
end
